#ifndef DSPAUDIOOUT_H_INCLUDED
#define DSPAUDIOOUT_H_INCLUDED

#include "../config.h"
#include "dspaudio.h"

class DspOut;

class DspAudioOut : public DspAudio
{
#ifndef QT_THREAD_SUPPORT
	Q_OBJECT
#endif
public:
	DspAudioOut( DspOut *in, DspOut *out );
	~DspAudioOut( void );

	/**
	 * Just do one tick, for non-threaded implementations.
	 */
	virtual void timerTick( void );

#ifndef QT_THREAD_SUPPORT
	virtual void start( void );

private slots:
	virtual void timeout( void );

#endif

private:
	unsigned int curpos;
};

#endif // DSPAUDIOOUT_H_INCLUDED
